import 'package:flutter/material.dart';
import 'package:workflow/component/application_install.dart';
import 'package:workflow/component/content_panel.dart';
import 'package:workflow/component/device_manager.dart';
import 'package:workflow/component/release_main.dart';

import 'component/debug_module.dart';
import 'component/info/baseinfo_page.dart';
import 'component/log_page.dart';
import 'component/log_utils.dart';
import 'component/sidebar.dart';
import 'utils/net_util.dart';

void main() {
  NetUtils.init('127.0.0.1:8080');
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Workflow',
      theme: ThemeData(
        primarySwatch: Colors.deepPurple, // TODO 主题色待定
        hoverColor: Colors.deepPurpleAccent,
        dividerTheme: DividerThemeData().copyWith(thickness: 1),
      ),
      home: HomePage(title: 'Home'),
    );
  }
}

class HomePage extends StatefulWidget {
  HomePage({Key key, this.title}) : super(key: key);
  final String title;

  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  final _titles = ['连接设备', 'Attach&热重载', 'Release构建', '日志', '环境'];
  final _widgets = [
    DeviceManager(),
    DebugModule(null),
    ReleaseMain(),
    LogPage(),
    BaseInfoPage(),
  ];
  int currentIndex = 0;

  @override
  void initState() {
    super.initState();
    logManager.connectSocketClient();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Row(
        children: <Widget>[
          Sidebar(
            menus: _titles,
            onTap: (index) => setState(() {
              currentIndex = index;
              logger.info('点击了${_titles[index]}');
            }),
            child: Column(
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                ApplicationInstall(),
                Container(
                  padding: EdgeInsets.only(left: 10, top: 10),
                  child: Text(
                    '友情提示：\n1. iOS目前只提供模拟器安装包，下载后先解压，再安装；\n2. 如遇Mac警告无法运行Demo，请执行sudo spctl --master-disable',
                    style: TextStyle(color: Colors.grey[700]),
                  ),
                )
              ],
            ),
          ),
          ContentPanel(
            title: _titles[currentIndex],
            builder: (context) => _widgets[currentIndex],
            hideBar: currentIndex == 3,
            darkTheme: true,
          )
        ],
      ),
    );
  }
}
